/**
 * Copyright (C) 2010, Claus Nielsen, cn@cn-consult.dk
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package dk.clanie.properties;


/**
 * Observable property interface.
 * 
 * Extends Property with a notification mechanism.
 * 
 * @author Claus Nielsen 
 *
 * @param <T> - the type of the property.
 */
public interface ObservableProperty<T> extends Property<T> {


	/**
	 * Adds a new listener to notify when the property's value is changed.
	 *
	 * @param listener
	 */
	void addChangeListener(PropertyChangeListener<T> listener);


	/**
	 * Un-regisers a previously registered PropertyChangeListener.
	 *
	 * @param listener
	 */
	void removeChangeListener(PropertyChangeListener<T> listener);
	

}
